componenttools.move_parentage_and_spanners_from_components_to_components
========================================================================

.. autofunction:: abjad.tools.componenttools.move_parentage_and_spanners_from_components_to_components.move_parentage_and_spanners_from_components_to_components
